"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveFile = exports.Repository = void 0;
const vscode = require("vscode");
const extName = 'vs-code-ingrid-modeler';
const os = require("os");
const path = require("path");
const fs = require('fs');
const jsdom = require("jsdom");
class Repository {
    constructor() {
        this.bpmnFiles = [];
    }
    newBPMNFile(uri) {
        this.bpmnFiles.push(new BPMNFile(uri));
    }
    getBPMNFile(uri) {
        for (let i = 0; i < this.bpmnFiles.length; i++) {
            if (this.bpmnFiles[i].uri && this.bpmnFiles[i].uri.fsPath === uri.fsPath) {
                return this.bpmnFiles[i];
            }
        }
        return null;
    }
    getBPMNFileByTmp(tmpUri) {
        for (let i = 0; i < this.bpmnFiles.length; i++) {
            if (this.bpmnFiles[i].tmpFile && this.bpmnFiles[i].tmpFile.fsPath === tmpUri.fsPath) {
                return this.bpmnFiles[i];
            }
        }
        return null;
    }
    updateBPMNFile(bpmnFile) {
        let index = this.getBPMNFileIndex(bpmnFile.uri);
        if (index > -1) {
            this.bpmnFiles[index] = bpmnFile;
        }
    }
    getBPMNFileIndex(uri) {
        for (let i = 0; i < this.bpmnFiles.length; i++) {
            if (this.bpmnFiles[i].uri && this.bpmnFiles[i].uri.fsPath === uri.fsPath) {
                return i;
            }
        }
        return -1;
    }
    openEditor(uri, id) {
        let tempdir = vscode.workspace.getConfiguration(extName).get('tmpDir') || os.tmpdir();
        var filepath = vscode.Uri.file(tempdir + path.sep + path.basename(uri.fsPath) + '.' + makeid(5) + '.tmpl');
        var bpmnFile = this.getBPMNFile(uri);
        if (bpmnFile) {
            if (bpmnFile.unsaved) {
                vscode.window.showErrorMessage('Could not load editor because you have unsaved changes.');
                return;
            }
            if (bpmnFile.tmpFile) {
                filepath = bpmnFile.tmpFile;
            }
            bpmnFile.tmpFile = filepath;
            bpmnFile.lastElementID = id;
            this.updateBPMNFile(bpmnFile);
            // Get content code from bpmn file
            let content = this.getCodeFromBPMNFile(bpmnFile, id);
            saveFile(filepath, content);
            vscode.workspace
                .openTextDocument(filepath)
                .then(document => {
                vscode.window.showTextDocument(document, vscode.ViewColumn.Beside, false);
                vscode.languages.setTextDocumentLanguage(document, 'gotemplate');
            });
        }
    }
    getCodeFromBPMNFile(bpmnFile, id) {
        var content = readFile(bpmnFile.uri);
        var dom = new jsdom.JSDOM(content, { contentType: "text/xml" });
        var nsPrefix = dom.window.document.firstElementChild.prefix;
        var elNode = dom.window.document
            .querySelector(`[id="${id}"] > ${nsPrefix}\\:documentation`);
        if (elNode !== null) {
            return elNode.textContent;
        }
        return "";
    }
}
exports.Repository = Repository;
class BPMNFile {
    constructor(uri) {
        this.uri = uri;
        this.unsaved = false;
        // this.tmpFile = {} as vscode.Uri;
        this.lastElementID = '';
    }
    setTmpFile(tmpFile) {
        this.tmpFile = tmpFile;
    }
    serializeWithNewCode(codeContent) {
        let bpmnContent = readFile(this.uri);
        if (bpmnContent) {
            let id = this.lastElementID;
            const dom = new jsdom.JSDOM(bpmnContent, { contentType: "text/xml" });
            var nsPrefix = dom.window.document.firstElementChild.prefix;
            var elNode = dom.window.document.querySelector(`[id="${id}"]`);
            if (elNode !== null) {
                var elDoc = elNode.querySelector(`${nsPrefix}\\:documentation`);
                if (elDoc !== null) {
                    elDoc.textContent = codeContent;
                }
                else {
                    var element = dom.window.document.createElement(`${nsPrefix}:documentation`);
                    element.textContent = codeContent;
                    element.id = "Documentation_" + makeid(8);
                    elNode.appendChild(element);
                }
                return dom.serialize();
            }
        }
        return "";
    }
}
/**
 * Functions
 */
function makeid(length) {
    var result = '';
    var characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
    var charactersLength = characters.length;
    for (var i = 0; i < length; i++) {
        result += characters.charAt(Math.floor(Math.random() * charactersLength));
    }
    return result;
}
function readFile(uri) {
    const { fsPath: docPath } = uri.with({ scheme: 'vscode-resource' });
    return fs.readFileSync(docPath, { encoding: 'utf8' });
}
function saveFile(uri, content) {
    const { fsPath: docPath } = uri.with({ scheme: 'vscode-resource' });
    if (!content && fs.existsSync(docPath)) {
        fs.unlinkSync(docPath);
    }
    fs.writeFileSync(docPath, content, { encoding: 'utf8' });
}
exports.saveFile = saveFile;
//# sourceMappingURL=repository.js.map