'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditingProvider = void 0;
const vscode = require("vscode");
const path = require("path");
const bpmnModelerBuilder_1 = require("./bpmnModelerBuilder");
const fs = require('fs');
class EditingProvider {
    constructor(_context) {
        this._context = _context;
    }
    getUri(webview, ...p) {
        const fileUri = vscode.Uri.file(path.join(this._context.extensionPath, ...p));
        return webview.asWebviewUri(fileUri);
    }
    provideTextDocumentContent(localResource, webview) {
        const localDocumentPath = localResource.fsPath;
        const contents = fs.readFileSync(localDocumentPath, { encoding: 'utf8' });
        const filePath = vscode.Uri.file(path.join(this._context.extensionPath, 'out', 'assets', 'editing.html'));
        var viewContent = fs.readFileSync(filePath.fsPath, 'utf8');
        const builder = new bpmnModelerBuilder_1.BpmnModelerBuilder(contents, viewContent, {
            modelerDistro: this.getUri(webview, 'node_modules', 'bpmn-js', 'dist', 'bpmn-modeler.development.js'),
            diagramStyles: this.getUri(webview, 'node_modules', 'bpmn-js', 'dist', 'assets', 'diagram-js.css'),
            bpmnFont: this.getUri(webview, 'node_modules', 'bpmn-js', 'dist', 'assets', 'bpmn-font', 'css', 'bpmn.css'),
            modelerStyles: this.getUri(webview, 'out', 'assets', 'modeler.css'),
            codiconsFont: this.getUri(webview, 'node_modules', 'vscode-codicons', 'dist', 'codicon.css'),
            resourceUri: localResource
        });
        return builder.buildModelerView();
    }
}
exports.EditingProvider = EditingProvider;
//# sourceMappingURL=editingProvider.js.map